@@ -11,23 +11,24 @@
 #ifndef AKONADI_INCIDENCECHANGER_P_H
 #define AKONADI_INCIDENCECHANGER_P_H
 
+#include "history.h"
 #include "incidencechanger.h"
 #include "itiphandlerhelper_p.h"
-#include "history.h"
 
-#include <item.h>
 #include <collection.h>
+#include <item.h>
 #include <transactionsequence.h>
 
-#include <QSet>
 #include <QObject>
 #include <QPointer>
+#include <QSet>
 #include <QVector>
 
 class KJob;
 class QWidget;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class TransactionSequence;
 class CollectionFetchJob;
 
@@ -35,8 +36,8 @@ class Change : public QObject
 {
     Q_OBJECT
 public:
-    typedef QSharedPointer<Change> Ptr;
-    typedef QVector<Ptr> List;
+    using Ptr = QSharedPointer<Change>;
+    using List = QVector<Ptr>;
     Change(IncidenceChanger *incidenceChanger, int changeId, IncidenceChanger::ChangeType changeType, uint operationId, QWidget *parent)
         : id(changeId)
         , type(changeType)
@@ -60,7 +61,7 @@ public:
 
     virtual void childAboutToDie(Change *child)
     {
-        Q_UNUSED(child);
+        Q_UNUSED(child)
     }
 
     virtual void emitCompletionSignal() = 0;
@@ -100,13 +101,13 @@ class ModificationChange : public Change
 {
     Q_OBJECT
 public:
-    typedef QSharedPointer<ModificationChange> Ptr;
+    using Ptr = QSharedPointer<ModificationChange>;
     ModificationChange(IncidenceChanger *changer, int id, uint atomicOperationId, QWidget *parent)
         : Change(changer, id, IncidenceChanger::ChangeTypeModify, atomicOperationId, parent)
     {
     }
 
-    ~ModificationChange()
+    ~ModificationChange() override
     {
         if (!parentChange) {
             emitCompletionSignal();
@@ -120,15 +121,15 @@ class CreationChange : public Change
 {
     Q_OBJECT
 public:
-    typedef QSharedPointer<CreationChange> Ptr;
+    using Ptr = QSharedPointer<CreationChange>;
     CreationChange(IncidenceChanger *changer, int id, uint atomicOperationId, QWidget *parent)
         : Change(changer, id, IncidenceChanger::ChangeTypeCreate, atomicOperationId, parent)
     {
     }
 
-    ~CreationChange()
+    ~CreationChange() override
     {
-        //qCDebug(AKONADICALENDAR_LOG) << "CreationChange::~ will emit signal with " << resultCode;
+        // qCDebug(AKONADICALENDAR_LOG) << "CreationChange::~ will emit signal with " << resultCode;
         if (!parentChange) {
             emitCompletionSignal();
         }
@@ -143,15 +144,15 @@ class DeletionChange : public Change
 {
     Q_OBJECT
 public:
-    typedef QSharedPointer<DeletionChange> Ptr;
+    using Ptr = QSharedPointer<DeletionChange>;
     DeletionChange(IncidenceChanger *changer, int id, uint atomicOperationId, QWidget *parent)
         : Change(changer, id, IncidenceChanger::ChangeTypeDelete, atomicOperationId, parent)
     {
     }
 
-    ~DeletionChange()
+    ~DeletionChange() override
     {
-        //qCDebug(AKONADICALENDAR_LOG) << "DeletionChange::~ will emit signal with " << resultCode;
+        // qCDebug(AKONADICALENDAR_LOG) << "DeletionChange::~ will emit signal with " << resultCode;
         if (!parentChange) {
             emitCompletionSignal();
         }
@@ -182,7 +183,7 @@ public:
 
     ~AtomicOperation()
     {
-        //qCDebug(AKONADICALENDAR_LOG) << "AtomicOperation::~ " << wasRolledback << changes.count();
+        // qCDebug(AKONADICALENDAR_LOG) << "AtomicOperation::~ " << wasRolledback << changes.count();
         if (m_wasRolledback) {
             for (int i = 0; i < m_changes.count(); ++i) {
                 // When a job that can finish successfully is aborted because the transaction failed
@@ -206,7 +207,7 @@ public:
 
     void setRolledback()
     {
-        //qCDebug(AKONADICALENDAR_LOG) << "AtomicOperation::setRolledBack()";
+        // qCDebug(AKONADICALENDAR_LOG) << "AtomicOperation::setRolledBack()";
         m_wasRolledback = true;
         transaction()->rollback();
     }
@@ -249,7 +250,7 @@ public:
     explicit Private(bool enableHistory, ITIPHandlerComponentFactory *factory, IncidenceChanger *mIncidenceChanger);
     ~Private();
 
-    void loadCollections();  // async-loading of list of writable collections
+    void loadCollections(); // async-loading of list of writable collections
     bool isLoadingCollections() const;
     Collection::List collectionsForMimeType(const QString &mimeType, const Collection::List &collections);
 
@@ -265,8 +266,6 @@ public:
 
     QString showErrorDialog(Akonadi::IncidenceChanger::ResultCode, QWidget *parent);
 
-    void setChangeInternal(int changeId);
-
     void adjustRecurrence(const KCalendarCore::Incidence::Ptr &originalIncidence, const KCalendarCore::Incidence::Ptr &incidence);
 
     bool hasRights(const Akonadi::Collection &collection, IncidenceChanger::ChangeType) const;
@@ -280,7 +279,8 @@ public:
 
     void handleInvitationsBeforeChange(const Change::Ptr &change);
     void handleInvitationsAfterChange(const Change::Ptr &change);
-    static bool myAttendeeStatusChanged(const KCalendarCore::Incidence::Ptr &newIncidence, const KCalendarCore::Incidence::Ptr &oldIncidence, const QStringList &myEmails);
+    static bool
+    myAttendeeStatusChanged(const KCalendarCore::Incidence::Ptr &newIncidence, const KCalendarCore::Incidence::Ptr &oldIncidence, const QStringList &myEmails);
 
 public Q_SLOTS:
     void handleCreateJobResult(KJob *job);
@@ -344,11 +344,12 @@ public:
 
     Akonadi::CollectionFetchJob *m_collectionFetchJob = nullptr;
 
-    QMap<KJob *, QSet<KCalendarCore::IncidenceBase::Field> > mDirtyFieldsByJob;
+    QMap<KJob *, QSet<KCalendarCore::IncidenceBase::Field>> mDirtyFieldsByJob;
 
     IncidenceChanger::InvitationPolicy m_invitationPolicy;
 
     ITIPHandlerComponentFactory *mFactory = nullptr;
+
 private:
     IncidenceChanger *q = nullptr;
 };
